@@ -37,7 +37,7 @@ Use clear, non-technical language. Format in Markdown with proper headings."""
             messages=[LLMMessage(role="user", content=overview_prompt)],
             system_prompt=system_prompt
         )
-        write_file(str(overview_dir / "index.md"), f"# Overview\n\n{response.content}")
+        write_file(str(overview_dir / "index.md"), f"# Overview\n\n{response.content}", sanitize_mdx=True)
         
         # 2. Architecture Overview with diagram
         module_map = self.analyzer.build_module_map(analyses)
@@ -71,7 +71,7 @@ Format in Markdown."""
 
 {arch_diagram}
 """
-        write_file(str(overview_dir / "architecture.md"), arch_content)
+        write_file(str(overview_dir / "architecture.md"), arch_content, sanitize_mdx=True)
         
         # 3. Technology Stack
         tech_prompt = f"""Based on this codebase analysis, document the technology stack:
@@ -91,7 +91,7 @@ Format as a well-structured Markdown document."""
             messages=[LLMMessage(role="user", content=tech_prompt)],
             system_prompt=system_prompt
         )
-        write_file(str(overview_dir / "technology-stack.md"), f"# Technology Stack\n\n{response.content}")
+        write_file(str(overview_dir / "technology-stack.md"), f"# Technology Stack\n\n{response.content}", sanitize_mdx=True)
         
         self.logger.info("Overview section completed")
     
@@ -124,7 +124,7 @@ Include code blocks and commands. Format in Markdown."""
             messages=[LLMMessage(role="user", content=install_prompt)],
             system_prompt=system_prompt
         )
-        write_file(str(getting_started_dir / "installation.md"), f"# Installation\n\n{response.content}")
+        write_file(str(getting_started_dir / "installation.md"), f"# Installation\n\n{response.content}", sanitize_mdx=True)
         
         # 2. Quick Start Guide with sequence diagram
         quickstart_prompt = f"""Create a quick start guide with step-by-step tutorial:
@@ -144,7 +144,7 @@ Use code examples. Format in Markdown."""
             messages=[LLMMessage(role="user", content=quickstart_prompt)],
             system_prompt=system_prompt
         )
-        write_file(str(getting_started_dir / "quick-start.md"), f"# Quick Start\n\n{response.content}")
+        write_file(str(getting_started_dir / "quick-start.md"), f"# Quick Start\n\n{response.content}", sanitize_mdx=True)
         
         # 3. Configuration Guide
         config_prompt = f"""Document the configuration options for this project:
@@ -164,7 +164,7 @@ Format in Markdown with tables for options."""
             messages=[LLMMessage(role="user", content=config_prompt)],
             system_prompt=system_prompt
         )
-        write_file(str(getting_started_dir / "configuration.md"), f"# Configuration\n\n{response.content}")
+        write_file(str(getting_started_dir / "configuration.md"), f"# Configuration\n\n{response.content}", sanitize_mdx=True)
         
         self.logger.info("Getting Started section completed")
     
@@ -209,7 +209,7 @@ Format as a comprehensive Markdown document with clear sections for each feature
             system_prompt=system_prompt
         )
         
-        write_file(str(features_dir / "index.md"), f"# Features\n\n{response.content}")
+        write_file(str(features_dir / "index.md"), f"# Features\n\n{response.content}", sanitize_mdx=True)
         
         self.logger.info("Feature sections completed")
     
@@ -260,7 +260,7 @@ Format in Markdown with extensive use of diagrams."""
 
 {arch_diagram}
 """
-        write_file(str(arch_dir / "components.md"), arch_content)
+        write_file(str(arch_dir / "components.md"), arch_content, sanitize_mdx=True)
         
         self.logger.info("Architecture section completed")
     
@@ -302,7 +302,7 @@ Format in Markdown with clear sections for each endpoint."""
             system_prompt=system_prompt
         )
         
-        write_file(str(api_dir / "endpoints.md"), f"# API Reference\n\n{response.content}")
+        write_file(str(api_dir / "endpoints.md"), f"# API Reference\n\n{response.content}", sanitize_mdx=True)
         
         self.logger.info("API Reference section completed")
     
@@ -351,23 +351,45 @@ This documentation focuses on:
 """
         
         output_path = Path(self.config.output.path) / "README.md"
-        write_file(str(output_path), index_content)
+        write_file(str(output_path), index_content, sanitize_mdx=True)
         
         self.logger.info("Documentation index completed")
     
     def _generate_docusaurus_sidebar(self, analyses: List[Dict[str, Any]]) -> None:
-        """Generate Docusaurus sidebar configuration automatically."""
+        """Generate Docusaurus sidebar configuration automatically based on actual file structure."""
         self.logger.info("Generating Docusaurus sidebar configuration")
         
-        # Determine the relative path from website root to docs
-        # Typically: website/docs/api-reference or just docs/api-reference
         output_path = Path(self.config.output.path)
         
-        # Try to determine if we're in a website/docs structure
-        sidebar_items_prefix = "api-reference"
-        if "website" in str(output_path):
-            # We're likely in website/docs/api-reference
-            sidebar_items_prefix = "api-reference"
+        # Find website root
+        website_root = None
+        current = output_path
+        for _ in range(5):  # Search up to 5 levels
+            current = current.parent
+            if (current / "package.json").exists() or (current / "docusaurus.config.ts").exists():
+                website_root = current
+                break
+        
+        if not website_root:
+            self.logger.warning("Could not find Docusaurus website root, skipping sidebar generation")
+            return
+        
+        # Determine the doc path prefix relative to website/docs
+        # If output_path is /path/to/website/docs, prefix is empty
+        # If output_path is /path/to/website/docs/api-reference, prefix is 'api-reference'
+        docs_dir = website_root / "docs"
+        try:
+            relative_to_docs = output_path.relative_to(docs_dir)
+            prefix = str(relative_to_docs) if str(relative_to_docs) != '.' else ''
+        except ValueError:
+            # output_path is not under website/docs
+            prefix = ''
+        
+        # Scan the output directory to build sidebar structure
+        sidebar_structure = self._scan_docs_structure(output_path, prefix)
+        
+        # Generate sidebar config
+        sidebar_items = self._build_sidebar_items(sidebar_structure)
         
         sidebar_config = f"""/**
  * Creating a sidebar enables you to:
@@ -385,77 +407,135 @@ This documentation focuses on:
 import type {{SidebarsConfig}} from '@docusaurus/plugin-content-docs';
 
 const sidebars: SidebarsConfig = {{
-  tutorialSidebar: [
-    {{
-      type: 'doc',
-      id: '{sidebar_items_prefix}/README',
-      label: 'Documentation Home',
-    }},
-    {{
-      type: 'category',
-      label: 'Overview',
-      collapsed: false,
-      items: [
-        '{sidebar_items_prefix}/overview/index',
-        '{sidebar_items_prefix}/overview/architecture',
-        '{sidebar_items_prefix}/overview/technology-stack',
-      ],
-    }},
-    {{
-      type: 'category',
-      label: 'Getting Started',
-      collapsed: false,
-      items: [
-        '{sidebar_items_prefix}/getting-started/installation',
-        '{sidebar_items_prefix}/getting-started/quick-start',
-        '{sidebar_items_prefix}/getting-started/configuration',
-      ],
-    }},
-    {{
-      type: 'category',
-      label: 'Features',
-      items: [
-        '{sidebar_items_prefix}/features/index',
-      ],
-    }},
-    {{
-      type: 'category',
-      label: 'Architecture',
-      items: [
-        '{sidebar_items_prefix}/architecture/components',
-      ],
-    }},
-  ],
+  tutorialSidebar: {sidebar_items},
 }};
 
 export default sidebars;
 """
         
-        # Try to find website root by going up from output path
-        website_root = None
-        current = output_path
-        for _ in range(5):  # Search up to 5 levels
-            current = current.parent
-            if (current / "package.json").exists() or (current / "docusaurus.config.ts").exists():
-                website_root = current
-                break
+        sidebar_path = website_root / "sidebars.ts"
+        write_file(str(sidebar_path), sidebar_config)
+        self.logger.info(f"Generated Docusaurus sidebar at: {sidebar_path}")
+    
+    def _scan_docs_structure(self, docs_path: Path, prefix: str) -> Dict[str, Any]:
+        """Scan documentation directory and build structure."""
+        structure = {
+            'readme': None,
+            'categories': {}
+        }
         
-        if website_root:
-            sidebar_path = website_root / "sidebars.ts"
-            write_file(str(sidebar_path), sidebar_config)
-            self.logger.info(f"Generated Docusaurus sidebar at: {sidebar_path}")
-        else:
-            # Fallback: save in output directory as a reference
-            sidebar_path = output_path / "sidebars.ts.example"
-            write_file(str(sidebar_path), sidebar_config)
-            self.logger.warning(f"Could not find Docusaurus website root. Saved example at: {sidebar_path}")
-            self.logger.warning("Please copy this to your Docusaurus website root and rename to sidebars.ts")
+        # Check for README
+        if (docs_path / "README.md").exists():
+            doc_id = f"{prefix}/README" if prefix else "README"
+            structure['readme'] = doc_id
+        
+        # Scan subdirectories
+        for item in sorted(docs_path.iterdir()):
+            if item.is_dir():
+                category_name = item.name
+                category_items = []
+                
+                # Scan files in this category
+                for doc_file in sorted(item.glob("*.md")):
+                    if doc_file.name == "README.md":
+                        continue  # Skip README in subdirs
+                    
+                    # Build doc ID without .md extension
+                    doc_name = doc_file.stem
+                    if prefix:
+                        doc_id = f"{prefix}/{category_name}/{doc_name}"
+                    else:
+                        doc_id = f"{category_name}/{doc_name}"
+                    
+                    category_items.append({
+                        'id': doc_id,
+                        'name': doc_name
+                    })
+                
+                if category_items:
+                    structure['categories'][category_name] = category_items
+        
+        return structure
+    
+    def _build_sidebar_items(self, structure: Dict[str, Any]) -> str:
+        """Build sidebar items JSON string from structure."""
+        items = []
+        
+        # Add README if exists
+        if structure['readme']:
+            items.append(f"""    {{
+      type: 'doc',
+      id: '{structure['readme']}',
+      label: 'Documentation Home',
+    }}""")
+        
+        # Define category order and labels
+        category_order = {
+            'overview': {'label': 'Overview', 'collapsed': False},
+            'getting-started': {'label': 'Getting Started', 'collapsed': False},
+            'features': {'label': 'Features', 'collapsed': False},
+            'architecture': {'label': 'Architecture', 'collapsed': False},
+            'api': {'label': 'API Reference', 'collapsed': True},
+            'guides': {'label': 'Guides', 'collapsed': False},
+        }
+        
+        # Build categories in order
+        for category_name in category_order.keys():
+            if category_name in structure['categories']:
+                category_info = category_order[category_name]
+                items.append(self._build_category_item(
+                    category_name,
+                    category_info['label'],
+                    structure['categories'][category_name],
+                    category_info['collapsed']
+                ))
+        
+        # Add remaining categories not in the predefined order
+        for category_name, category_items in structure['categories'].items():
+            if category_name not in category_order:
+                label = category_name.replace('-', ' ').replace('_', ' ').title()
+                items.append(self._build_category_item(
+                    category_name,
+                    label,
+                    category_items,
+                    False
+                ))
+        
+        return "[\n" + ",\n".join(items) + ",\n  ]"
+    
+    def _build_category_item(self, category_name: str, label: str, items: List[Dict[str, str]], collapsed: bool) -> str:
+        """Build a single category item for sidebar."""
+        # Define preferred order for common doc names
+        doc_order = ['index', 'installation', 'quick-start', 'configuration', 'architecture', 'technology-stack', 'components']
+        
+        # Sort items by preferred order, then alphabetically
+        def sort_key(item):
+            name = item['name']
+            if name in doc_order:
+                return (0, doc_order.index(name))
+            return (1, name)
+        
+        sorted_items = sorted(items, key=sort_key)
+        
+        # Build items list
+        item_ids = [f"        '{item['id']}'" for item in sorted_items]
+        items_str = ",\n".join(item_ids)
+        
+        return f"""    {{
+      type: 'category',
+      label: '{label}',
+      collapsed: {str(collapsed).lower()},
+      items: [
+{items_str}
+      ],
+    }}"""
     
     def _update_docusaurus_config(self, analyses: List[Dict[str, Any]]) -> None:
-        """Update Docusaurus config with GitHub repository information."""
+        """Generate/update comprehensive Docusaurus configuration with AI-powered content."""
         from sourcescribe.utils.github_utils import get_github_url_from_git
+        import re
         
-        self.logger.info("Updating Docusaurus configuration")
+        self.logger.info("Generating Docusaurus configuration")
         
         # Get GitHub URL
         github_url = self.config.repository.github_url
@@ -463,18 +543,19 @@ export default sidebars;
             github_url = get_github_url_from_git(self.config.repository.path)
         
         if not github_url:
-            self.logger.warning("No GitHub URL found, skipping Docusaurus config update")
-            return
-        
-        # Parse GitHub URL to get org and repo
-        # Format: https://github.com/org/repo
-        try:
-            parts = github_url.rstrip('/').split('/')
-            org_name = parts[-2]
-            repo_name = parts[-1]
-        except (IndexError, AttributeError):
-            self.logger.warning(f"Could not parse GitHub URL: {github_url}")
-            return
+            self.logger.warning("No GitHub URL found, using defaults for Docusaurus config")
+            org_name = "your-org"
+            repo_name = "your-repo"
+        else:
+            # Parse GitHub URL to get org and repo
+            try:
+                parts = github_url.rstrip('/').split('/')
+                org_name = parts[-2]
+                repo_name = parts[-1].replace('.git', '')
+            except (IndexError, AttributeError):
+                self.logger.warning(f"Could not parse GitHub URL: {github_url}")
+                org_name = "your-org"
+                repo_name = "your-repo"
         
         # Try to find docusaurus.config.ts
         output_path = Path(self.config.output.path)
@@ -494,31 +575,255 @@ export default sidebars;
         
         config_path = website_root / "docusaurus.config.ts"
         
+        # Infer project title from repo name or README
+        title = self._infer_project_title(repo_name, analyses)
+        
+        # Generate tagline using AI
+        tagline = self._generate_tagline(analyses)
+        
+        # Generate the complete Docusaurus config
+        config_content = self._generate_docusaurus_config_content(
+            title=title,
+            tagline=tagline,
+            github_url=github_url if github_url else f"https://github.com/{org_name}/{repo_name}",
+            org_name=org_name,
+            repo_name=repo_name
+        )
+        
         try:
-            # Read existing config
-            with open(config_path, 'r') as f:
-                config_content = f.read()
-            
-            # Update organizationName
-            import re
-            config_content = re.sub(
-                r"organizationName:\s*['\"]([^'\"]*)['\"]",
-                f"organizationName: '{org_name}'",
-                config_content
-            )
-            
-            # Update projectName
-            config_content = re.sub(
-                r"projectName:\s*['\"]([^'\"]*)['\"]",
-                f"projectName: '{repo_name}'",
-                config_content
-            )
-            
-            # Write back
             write_file(str(config_path), config_content)
-            self.logger.info(f"Updated Docusaurus config at: {config_path}")
-            self.logger.info(f"  - organizationName: {org_name}")
-            self.logger.info(f"  - projectName: {repo_name}")
-            
+            self.logger.info(f"Generated Docusaurus config at: {config_path}")
+            self.logger.info(f"  - Title: {title}")
+            self.logger.info(f"  - Tagline: {tagline}")
+            self.logger.info(f"  - Organization: {org_name}")
+            self.logger.info(f"  - Project: {repo_name}")
         except Exception as e:
             self.logger.error(f"Failed to update Docusaurus config: {e}")
+    
+    def _infer_project_title(self, repo_name: str, analyses: List[Dict[str, Any]]) -> str:
+        """Infer project title from repo name and analysis."""
+        # Check if there's a clear project name in README or package.json
+        repo_path = Path(self.config.repository.path)
+        
+        # Try package.json first
+        package_json = repo_path / "package.json"
+        if package_json.exists():
+            try:
+                import json
+                with open(package_json) as f:
+                    data = json.load(f)
+                    if 'name' in data and not data['name'].startswith('@'):
+                        return data['name'].replace('-', ' ').title()
+            except:
+                pass
+        
+        # Try pyproject.toml
+        pyproject = repo_path / "pyproject.toml"
+        if pyproject.exists():
+            try:
+                import re
+                with open(pyproject) as f:
+                    content = f.read()
+                    match = re.search(r'name\s*=\s*["\']([^"\']+)["\']', content)
+                    if match:
+                        return match.group(1).replace('-', ' ').title()
+            except:
+                pass
+        
+        # Fallback to formatted repo name
+        return repo_name.replace('-', ' ').replace('_', ' ').title()
+    
+    def _generate_tagline(self, analyses: List[Dict[str, Any]]) -> str:
+        """Generate a catchy tagline using AI."""
+        self.logger.info("Generating project tagline with AI")
+        
+        # Build context from analyses
+        context = self._build_project_context(analyses, max_files=5)
+        
+        prompt = f"""Based on this codebase analysis, generate a concise, catchy tagline (max 80 characters).
+
+{context}
+
+Requirements:
+- Under 80 characters
+- Clear and descriptive
+- Professional but engaging
+- No buzzwords or jargon
+- Focus on what the project does and who it's for
+
+Return ONLY the tagline text, nothing else."""
+
+        try:
+            messages = [
+                LLMMessage(role="system", content=self._get_system_prompt()),
+                LLMMessage(role="user", content=prompt)
+            ]
+            
+            response = self.llm_provider.generate(messages)
+            tagline = response.strip().strip('"').strip("'")
+            
+            # Validate length
+            if len(tagline) > 100:
+                tagline = tagline[:97] + "..."
+            
+            return tagline
+        except Exception as e:
+            self.logger.warning(f"Failed to generate tagline with AI: {e}")
+            return "Auto-generated documentation for your project"
+    
+    def _generate_docusaurus_config_content(
+        self,
+        title: str,
+        tagline: str,
+        github_url: str,
+        org_name: str,
+        repo_name: str
+    ) -> str:
+        """Generate complete Docusaurus configuration content."""
+        
+        # Determine if we're outputting to a subdirectory
+        output_path = Path(self.config.output.path)
+        website_root = output_path.parent.parent if 'docs' in str(output_path) else output_path.parent
+        
+        # Try to find if docs are in a subdirectory
+        docs_dir = website_root / "docs"
+        
+        config = f"""import {{themes as prismThemes}} from 'prism-react-renderer';
+import type {{Config}} from '@docusaurus/types';
+import type * as Preset from '@docusaurus/preset-classic';
+
+const config: Config = {{
+  title: '{title}',
+  tagline: '{tagline}',
+  favicon: 'img/favicon.ico',
+
+  // Future flags, see https://docusaurus.io/docs/api/docusaurus-config#future
+  future: {{
+    v4: true,
+  }},
+
+  // Set the production url of your site here
+  url: 'https://{org_name}.github.io',
+  // Set the /<baseUrl>/ pathname under which your site is served
+  baseUrl: '/{repo_name}/',
+
+  // GitHub pages deployment config
+  organizationName: '{org_name}',
+  projectName: '{repo_name}',
+
+  onBrokenLinks: 'warn',
+  onBrokenMarkdownLinks: 'warn',
+
+  i18n: {{
+    defaultLocale: 'en',
+    locales: ['en'],
+  }},
+
+  presets: [
+    [
+      'classic',
+      {{
+        docs: {{
+          sidebarPath: './sidebars.ts',
+          editUrl: '{github_url}/tree/main/website/',
+        }},
+        blog: false,
+        theme: {{
+          customCss: './src/css/custom.css',
+        }},
+      }} satisfies Preset.Options,
+    ],
+  ],
+
+  markdown: {{
+    mermaid: true,
+  }},
+  themes: ['@docusaurus/theme-mermaid'],
+
+  themeConfig: {{
+    mermaid: {{
+      theme: {{light: 'neutral', dark: 'dark'}},
+      options: {{
+        fontSize: 16,
+        nodeSpacing: 50,
+        rankSpacing: 50,
+        curve: 'basis',
+        padding: 15,
+      }},
+    }},
+    image: 'img/social-card.jpg',
+    colorMode: {{
+      respectPrefersColorScheme: true,
+    }},
+    navbar: {{
+      title: '{title}',
+      logo: {{
+        alt: '{title} Logo',
+        src: 'img/logo.svg',
+      }},
+      items: [
+        {{
+          type: 'docSidebar',
+          sidebarId: 'tutorialSidebar',
+          position: 'left',
+          label: 'Documentation',
+        }},
+        {{
+          href: '{github_url}',
+          label: 'GitHub',
+          position: 'right',
+        }},
+      ],
+    }},
+    footer: {{
+      style: 'dark',
+      links: [
+        {{
+          title: 'Documentation',
+          items: [
+            {{
+              label: 'Getting Started',
+              to: '/docs/getting-started/installation',
+            }},
+            {{
+              label: 'Overview',
+              to: '/docs/overview/index',
+            }},
+          ],
+        }},
+        {{
+          title: 'Community',
+          items: [
+            {{
+              label: 'GitHub',
+              href: '{github_url}',
+            }},
+            {{
+              label: 'Issues',
+              href: '{github_url}/issues',
+            }},
+          ],
+        }},
+        {{
+          title: 'More',
+          items: [
+            {{
+              label: 'Repository',
+              href: '{github_url}',
+            }},
+          ],
+        }},
+      ],
+      copyright: `Copyright © ${{new Date().getFullYear()}} {title}. Built with Docusaurus.`,
+    }},
+    prism: {{
+      theme: prismThemes.github,
+      darkTheme: prismThemes.dracula,
+      additionalLanguages: ['bash', 'json', 'python', 'typescript', 'javascript'],
+    }},
+  }} satisfies Preset.ThemeConfig,
+}};
+
+export default config;
+"""
+        return config
